# PyPiSearch
One more replacement of temporarily deprecated pip search command implemented on regular expressions and uses [pypi site](https://pypi.org/) search line.

## Install and run
- Clone this repo and run `python pypisearch <query>`
- Install it by pip `pip install pypisearch` and run `python -m pypisearch <query>`